searchData={"items":[{"type":"module","title":"CozyLogger","doc":"Logging helpers, providing format functions of various formats and seamless integrations with other libraries.","ref":"CozyLogger.html"},{"type":"module","title":"Features - CozyLogger","doc":"- Formats\n  - [x] JSON\n  - ...\n- Integrations\n  - [x] Phoenix\n  - [ ] Ecto\n  - ...","ref":"CozyLogger.html#module-features"},{"type":"module","title":"Installation - CozyLogger","doc":"[Install it from Hex](https://hex.pm/packages/cozy_logger).","ref":"CozyLogger.html#module-installation"},{"type":"module","title":"Usage - CozyLogger","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_logger).","ref":"CozyLogger.html#module-usage"},{"type":"module","title":"About the design - CozyLogger","doc":"- The **formats** are only responsible for formatting, and they do not handle any vendor-specific formats.\n- The **integrations** process telemetry events to print logs, and provide `install/0` or `install/1` functions for convenient initialization.","ref":"CozyLogger.html#module-about-the-design"},{"type":"module","title":"License - CozyLogger","doc":"Apache License 2.0","ref":"CozyLogger.html#module-license"},{"type":"module","title":"CozyLogger.JSON","doc":"Formatting log messages as JSON.","ref":"CozyLogger.JSON.html"},{"type":"module","title":"Usage - CozyLogger.JSON","doc":"Elixir v1.15 or later:\n\n    # customize format message with this formatter.\n    config :logger, :default_formatter,\n      format: {CozyLogger.JSON, :format},\n      truncate: :infinity,\n      utc_log: true,\n      metadata: :all,\n      colors: [enabled: false]\n\nPrior to Elixir v1.15:\n\n    # use Elixir built-in console backend, and configure other necessary options\n    config :logger,\n      backends: [:console],\n      truncate: :infinity,\n      utc_log: true\n\n    # customize format message with this formatter.\n    config :logger, :console,\n      format: {CozyLogger.JSON, :format},\n      metadata: :all,\n      colors: [enabled: false]","ref":"CozyLogger.JSON.html#module-usage"},{"type":"function","title":"CozyLogger.JSON.format/4","doc":"","ref":"CozyLogger.JSON.html#format/4"},{"type":"type","title":"CozyLogger.JSON.date/0","doc":"","ref":"CozyLogger.JSON.html#t:date/0"},{"type":"type","title":"CozyLogger.JSON.date_time_ms/0","doc":"","ref":"CozyLogger.JSON.html#t:date_time_ms/0"},{"type":"type","title":"CozyLogger.JSON.time_ms/0","doc":"","ref":"CozyLogger.JSON.html#t:time_ms/0"},{"type":"module","title":"CozyLogger.PhoenixIntegration","doc":"`CozyLogger` integration for `Phoenix`.\n\nPhoenix uses the `:telemetry` library for instrumentation. The following events\nare published by Phoenix:\n\n  * `[:phoenix, :endpoint, :start]`\n  * `[:phoenix, :endpoint, :stop]`\n  * `[:phoenix, :router_dispatch, :start]`\n  * `[:phoenix, :error_rendered]`\n  * `[:phoenix, :socket_connected]`\n  * `[:phoenix, :channel_joined]`\n  * `[:phoenix, :channel_handled_in]`\n\n`Phoenix.Logger`(the default logger) handles these events, and print logs accordingly.","ref":"CozyLogger.PhoenixIntegration.html"},{"type":"module","title":"Usage - CozyLogger.PhoenixIntegration","doc":"Before using this custom logger, you need to disable the default logger:\n\n    config :phoenix, :logger, false\n\nThen, you need to attach events handlers before starting the application:\n\n    defmodule Demo\n      use Application\n\n      def start(_type, _args) do\n        unless Application.fetch_env!(:phoenix, :logger) do\n          CozyLogger.PhoenixIntegration.install()\n        end\n\n        children = [\n          # ...\n        ]\n\n        Supervisor.start_link(children, strategy: :one_for_one, name: Demo.Supervisor)\n      end\n    end","ref":"CozyLogger.PhoenixIntegration.html#module-usage"},{"type":"module","title":"Parameter filtering - CozyLogger.PhoenixIntegration","doc":"When logging parameters, CozyLogger.PhoenixIntegration can filter out sensitive parameters\nsuch as passwords and tokens. Parameters to be filtered can be added via the\n`:filter_params` option:\n\n    CozyLogger.PhoenixIntegration.install(filter_params: [\"password\", \"secret\"])\n\nWith the configuration above, CozyLogger.PhoenixIntegration will filter any parameter that\ncontains the terms `password` or `secret`. The match is case sensitive.\n\nThe default value of `:filter_params` option is `[\"password\"]`.\n\nCozyLogger.PhoenixIntegration can also filter all parameters by default and selectively keep\nparameters. This can be configured like so:\n\n    CozyLogger.PhoenixIntegration.install(filter_params: {:keep, [\"id\", \"order\"]})\n\nWith the configuration above, CozyLogger.PhoenixIntegration will filter all parameters,\nexcept those that match exactly `id` or `order`. If a kept parameter matches,\nall parameters nested under that one will also be kept.","ref":"CozyLogger.PhoenixIntegration.html#module-parameter-filtering"},{"type":"module","title":"Dynamic log level - CozyLogger.PhoenixIntegration","doc":"In some cases you may wish to set the log level dynamically on a per-request basis.\n\nTo do so, set the `:log` option to a tuple, `{Mod, Fun, Args}`. The `Plug.Conn.t()` for the\nrequest will be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a [`Logger.level()`](`t:Logger.level()/0`) or `false`\nto disable logging for the request.\n\nFor example, in your Endpoint you might do something like this:\n\n      # lib/demo_web/endpoint.ex\n      plug Plug.Telemetry,\n        event_prefix: [:phoenix, :endpoint],\n        log: {__MODULE__, :log_level, []}\n\n      # Disables logging for routes like /status/*\n      def log_level(%{path_info: [\"status\" | _]}), do: false\n      def log_level(_), do: :info","ref":"CozyLogger.PhoenixIntegration.html#module-dynamic-log-level"},{"type":"module","title":"TODO - CozyLogger.PhoenixIntegration","doc":"Currently, only the handler for `[:phoenix, :endpoint, :stop]` is implemented.\n\nIf you need handlers for other events, feel free to contribute.","ref":"CozyLogger.PhoenixIntegration.html#module-todo"},{"type":"function","title":"CozyLogger.PhoenixIntegration.install/1","doc":"","ref":"CozyLogger.PhoenixIntegration.html#install/1"},{"type":"extras","title":"CozyLogger","doc":"# CozyLogger\n\n[![CI](https://github.com/cozy-elixir/cozy_logger/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_logger/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_logger.svg)](https://hex.pm/packages/cozy_logger)\n[![built with Nix](https://img.shields.io/badge/built%20with%20Nix-5277C3?logo=nixos&logoColor=white)](https://builtwithnix.org)\n\n<!-- MDOC -->\n\nLogging helpers, providing format functions of various formats and seamless integrations with other libraries.","ref":"readme.html"},{"type":"extras","title":"Features - CozyLogger","doc":"- Formats\n  - [x] JSON\n  - ...\n- Integrations\n  - [x] Phoenix\n  - [ ] Ecto\n  - ...","ref":"readme.html#features"},{"type":"extras","title":"Installation - CozyLogger","doc":"[Install it from Hex](https://hex.pm/packages/cozy_logger).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozyLogger","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_logger).","ref":"readme.html#usage"},{"type":"extras","title":"About the design - CozyLogger","doc":"- The **formats** are only responsible for formatting, and they do not handle any vendor-specific formats.\n- The **integrations** process telemetry events to print logs, and provide `install/0` or `install/1` functions for convenient initialization.","ref":"readme.html#about-the-design"},{"type":"extras","title":"License - CozyLogger","doc":"Apache License 2.0","ref":"readme.html#license"}],"content_type":"text/markdown"}